==> haskell-resource-pool-0.2.3.2-350-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 resource-pool
version:              0.2.3.2
visibility:           public
id:                   resource-pool-0.2.3.2-1IAL1hRKBL1GrOGhYvkTiF
key:                  resource-pool-0.2.3.2-1IAL1hRKBL1GrOGhYvkTiF
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://github.com/bos/pool
synopsis:             A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.

category:             Data, Database, Network
abi:                  f9f2e315aba6a7288ffe20e07d839dcf
exposed:              True
exposed-modules:      Data.Pool
import-dirs:          /usr/lib/ghc-9.4.8/site-local/resource-pool-0.2.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/resource-pool-0.2.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resource-pool
hs-libraries:         HSresource-pool-0.2.3.2-1IAL1hRKBL1GrOGhYvkTiF
depends:
    base-4.17.2.1 hashable-1.4.4.0-1zcla4qwUGf6ADT5z5m7Nb
    monad-control-1.0.3.1-C6ihb2mA0cN3fEkZdc54bR stm-2.5.1.0
    time-1.12.2 transformers-0.5.6.2
    transformers-base-0.4.6-1RrXnB8zjUD49zGEBaVH09
    vector-0.13.2.0-GjxrA8HCtQq4MGRlxeWifh

haddock-interfaces:
    /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock

haddock-html:         /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resource-pool-0.2.3.2-351-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 resource-pool
version:              0.2.3.2
visibility:           public
id:                   resource-pool-0.2.3.2-9pY30h3Q5a1HDMTKsGpvMS
key:                  resource-pool-0.2.3.2-9pY30h3Q5a1HDMTKsGpvMS
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://github.com/bos/pool
synopsis:             A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.

category:             Data, Database, Network
abi:                  48aff92fee3f831b4a80d20fa5422068
exposed:              True
exposed-modules:      Data.Pool
import-dirs:          /usr/lib/ghc-9.4.8/site-local/resource-pool-0.2.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/resource-pool-0.2.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resource-pool
hs-libraries:         HSresource-pool-0.2.3.2-9pY30h3Q5a1HDMTKsGpvMS
depends:
    base-4.17.2.1 hashable-1.4.4.0-9uPnQxUdwOnCZlD9EiHqMs
    monad-control-1.0.3.1-3LLy3Mh8aXAIWrcnISzEs0 stm-2.5.1.0
    time-1.12.2 transformers-0.5.6.2
    transformers-base-0.4.6-8PLbLN0z4cRFaAru9ySoP6
    vector-0.13.2.0-GniUvXn58d91eC1W7jmZ0

haddock-interfaces:
    /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock

haddock-html:         /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
